aboutsummaryrefslogtreecommitdiffstats
path: root/addressbook/backend/ebook/e-card-simple.h
diff options
context:
space:
mode:
authorJP Rosevear <jpr@ximian.com>2003-03-05 06:00:57 +0800
committerJP Rosevear <jpr@src.gnome.org>2003-03-05 06:00:57 +0800
commitc1e2563e393921af0dea2d29eeb13d58e1bcd91b (patch)
treecb97e52d92dffc93570bc244a9f8da769129c113 /addressbook/backend/ebook/e-card-simple.h
parent3703e58fa89f7644f50426288c4fc8f9325773ce (diff)
downloadgsoc2013-evolution-c1e2563e393921af0dea2d29eeb13d58e1bcd91b.tar
gsoc2013-evolution-c1e2563e393921af0dea2d29eeb13d58e1bcd91b.tar.gz
gsoc2013-evolution-c1e2563e393921af0dea2d29eeb13d58e1bcd91b.tar.bz2
gsoc2013-evolution-c1e2563e393921af0dea2d29eeb13d58e1bcd91b.tar.lz
gsoc2013-evolution-c1e2563e393921af0dea2d29eeb13d58e1bcd91b.tar.xz
gsoc2013-evolution-c1e2563e393921af0dea2d29eeb13d58e1bcd91b.tar.zst
gsoc2013-evolution-c1e2563e393921af0dea2d29eeb13d58e1bcd91b.zip
reflect prior column addition
2003-03-04 JP Rosevear <jpr@ximian.com> * gui/component/select-names/e-select-names.etspec: reflect prior column addition * gui/component/select-names/e-select-names-bonobo.c (entry_get_property_fn): set the arg properly * gui/component/select-names/Evolution-Addressbook-SelectNames.idl: add Icscalendar to field list * backend/pas/pas-backend-ldap.c: add icscalendar to prop list * backend/ebook/e-card.h: add icscalendar data member * backend/ebook/e-card.c: add icscalendar to list and its parse routine (e_card_get_vobject): add icscalendar prop value (parse_icscalendar): parse routine (e_card_class_init): add icscalendar arg (e_card_destroy): destroy icscalendar member (e_card_set_arg): set icscalendar (e_card_init): init icscalendar (e_card_get_arg): return icscalendar * backend/ebook/e-card-simple.c (field_data): add icscalendar * backend/ebook/e-card-simple.h: ditto svn path=/trunk/; revision=20153
Diffstat (limited to 'addressbook/backend/ebook/e-card-simple.h')
-rw-r--r--addressbook/backend/ebook/e-card-simple.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/addressbook/backend/ebook/e-card-simple.h b/addressbook/backend/ebook/e-card-simple.h
index 9e77a43ae1..868d4e1573 100644
--- a/addressbook/backend/ebook/e-card-simple.h
+++ b/addressbook/backend/ebook/e-card-simple.h
@@ -118,8 +118,9 @@ enum _ECardSimpleField {
E_CARD_SIMPLE_FIELD_NOTE,
E_CARD_SIMPLE_FIELD_CALURI,
E_CARD_SIMPLE_FIELD_FBURL,
- /* If you add after FBURL, make sure to move LAST_SIMPLE_STRING */
- E_CARD_SIMPLE_FIELD_LAST_SIMPLE_STRING = E_CARD_SIMPLE_FIELD_FBURL,
+ E_CARD_SIMPLE_FIELD_ICSCALENDAR,
+ /* If you add after icscalendar, make sure to move LAST_SIMPLE_STRING */
+ E_CARD_SIMPLE_FIELD_LAST_SIMPLE_STRING = E_CARD_SIMPLE_FIELD_ICSCALENDAR,
E_CARD_SIMPLE_FIELD_ANNIVERSARY,
E_CARD_SIMPLE_FIELD_BIRTH_DATE,
E_CARD_SIMPLE_FIELD_MAILER,